@@ -95,15 +95,6 @@ static int add_next_to_inflatable_buffer(struct inflatable_buffer *buffer)
 	return 0;
 }
 
-static void warn_unrecognized(const char *which)
-{
-	static bool once = false;
-	if (once)
-		return;
-	once = true;
-	fprintf(stderr, "Warning: one or more unrecognized %s attributes\n", which);
-}
-
 static FILE *userspace_interface_file(const char *interface)
 {
 	struct stat sbuf;
@@ -303,7 +294,7 @@ static int userspace_get_device(struct wgdevice **out, const char *interface)
 	FILE *f;
 	int ret = -EPROTO;
 
-	*out = dev = calloc(1, sizeof(struct wgdevice));
+	*out = dev = calloc(1, sizeof(*dev));
 	if (!dev)
 		return -errno;
 
@@ -341,7 +332,7 @@ static int userspace_get_device(struct wgdevice **out, const char *interface)
 			dev->fwmark = NUM(0xffffffffU);
 			dev->flags |= WGDEVICE_HAS_FWMARK;
 		} else if (!strcmp(key, "public_key")) {
-			struct wgpeer *new_peer = calloc(1, sizeof(struct wgpeer));
+			struct wgpeer *new_peer = calloc(1, sizeof(*new_peer));
 
 			if (!new_peer) {
 				ret = -ENOMEM;
@@ -407,7 +398,7 @@ static int userspace_get_device(struct wgdevice **out, const char *interface)
 
 			if (!mask || !isdigit(mask[0]))
 				break;
-			new_allowedip = calloc(1, sizeof(struct wgallowedip));
+			new_allowedip = calloc(1, sizeof(*new_allowedip));
 			if (!new_allowedip) {
 				ret = -ENOMEM;
 				goto err;
@@ -438,8 +429,6 @@ static int userspace_get_device(struct wgdevice **out, const char *interface)
 			peer->tx_bytes = NUM(0xffffffffffffffffULL);
 		else if (!strcmp(key, "errno"))
 			ret = -NUM(0x7fffffffU);
-		else
-			warn_unrecognized("daemon");
 	}
 	ret = -EPROTO;
 err:
@@ -711,8 +700,6 @@ static int parse_allowedip(const struct nlattr *attr, void *data)
 		if (!mnl_attr_validate(attr, MNL_TYPE_U8))
 			allowedip->cidr = mnl_attr_get_u8(attr);
 		break;
-	default:
-		warn_unrecognized("netlink");
 	}
 
 	return MNL_CB_OK;
@@ -721,7 +708,7 @@ static int parse_allowedip(const struct nlattr *attr, void *data)
 static int parse_allowedips(const struct nlattr *attr, void *data)
 {
 	struct wgpeer *peer = data;
-	struct wgallowedip *new_allowedip = calloc(1, sizeof(struct wgallowedip));
+	struct wgallowedip *new_allowedip = calloc(1, sizeof(*new_allowedip));
 	int ret;
 
 	if (!new_allowedip) {
@@ -792,8 +779,6 @@ static int parse_peer(const struct nlattr *attr, void *data)
 		break;
 	case WGPEER_A_ALLOWEDIPS:
 		return mnl_attr_parse_nested(attr, parse_allowedips, peer);
-	default:
-		warn_unrecognized("netlink");
 	}
 
 	return MNL_CB_OK;
@@ -802,7 +787,7 @@ static int parse_peer(const struct nlattr *attr, void *data)
 static int parse_peers(const struct nlattr *attr, void *data)
 {
 	struct wgdevice *device = data;
-	struct wgpeer *new_peer = calloc(1, sizeof(struct wgpeer));
+	struct wgpeer *new_peer = calloc(1, sizeof(*new_peer));
 	int ret;
 
 	if (!new_peer) {
@@ -862,8 +847,6 @@ static int parse_device(const struct nlattr *attr, void *data)
 		break;
 	case WGDEVICE_A_PEERS:
 		return mnl_attr_parse_nested(attr, parse_peers, device);
-	default:
-		warn_unrecognized("netlink");
 	}
 
 	return MNL_CB_OK;
@@ -903,7 +886,7 @@ static int kernel_get_device(struct wgdevice **device, const char *interface)
 	struct mnlg_socket *nlg;
 
 try_again:
-	*device = calloc(1, sizeof(struct wgdevice));
+	*device = calloc(1, sizeof(**device));
 	if (!*device)
 		return -errno;
 
